=======
pyravia
=======

Library to control Sony TVs and Stereos

Sony makes excellent TVs and Stereos, but like old-school yutzes
does not publish the API to control them. (something something official
integration partners something something corruption something something)

That's ok though - since all of the network interactions are done in clear
text over the network, making them pretty easy to figure out.

Making it all even better, there is a different API for the TV than for the
Stereo. YAY!

This has been tested against a XBR75X850D TV and a STR-ZA5000ES receiver.

This library was inspired by the work in:
https://github.com/breunigs/bravia-auth-and-remote

* Free software: GPL License
